@@ -69,78 +69,6 @@ class EfsFilingLogCd(CalAccessBaseModel):
         verbose_name_plural = 'EFS_FILING_LOG_CD'
 
 
-class FilernameCd(CalAccessBaseModel):
-    """
-    A combination of Cal-Access tables to provide the analyst with
-    filer information.
-
-    Note: Name last can also be the full name of the filer
-    (for both Campaign and lobbying filing entities).
-
-    Full name of all pacs, firms, and employers are always in this last
-    name field.
-
-    Major donors can be split between first and last name fields, but usually
-    are contained in the last name field only. Individual names of lobbyists,
-    candidates/officeholders, treasurers/responsible officers, and major donors
-    (when they are only an individual's name) use both the first and last name
-    fields in conjunction.
-    """
-    DATE_FIELDS = ('EFFECT_DT',)
-    xref_filer_id = models.CharField(
-        max_length=7L,
-        db_column='XREF_FILER_ID',
-        db_index=True,
-        help_text="The external filer id saved in the forms tables"
-    )
-    filer_id = models.IntegerField(
-        db_column='FILER_ID',
-        db_index=True,
-        null=True,
-        help_text="The internal filer id saved in Cal-Access"
-    )
-    filer_type = models.CharField(max_length=45L, db_column='FILER_TYPE')
-    status = models.CharField(max_length=10L, db_column='STATUS')
-    effect_dt = models.DateField(
-        db_column='EFFECT_DT',
-        help_text="Effective date for status",
-    )
-    naml = models.CharField(
-        max_length=200L, db_column='NAML',
-        help_text="Last name, (though sometimes the full name)"
-    )
-    namf = models.CharField(
-        max_length=55L, db_column='NAMF', blank=True,
-        help_text="First name"
-    )
-    namt = models.CharField(
-        max_length=28L, db_column='NAMT', blank=True,
-        help_text="Name prefix or title"
-    )
-    nams = models.CharField(
-        max_length=32L, db_column='NAMS', blank=True,
-        help_text="Name suffix"
-    )
-    adr1 = models.CharField(max_length=200L, db_column='ADR1', blank=True)
-    adr2 = models.CharField(max_length=200L, db_column='ADR2', blank=True)
-    city = models.CharField(max_length=55L, db_column='CITY', blank=True)
-    st = models.CharField(max_length=4L, db_column='ST', blank=True)
-    zip4 = models.CharField(max_length=10L, db_column='ZIP4', blank=True)
-    phon = models.CharField(max_length=60L, db_column='PHON', blank=True)
-    fax = models.CharField(max_length=60L, db_column='FAX', blank=True)
-    email = models.CharField(max_length=60L, db_column='EMAIL', blank=True)
-
-    class Meta:
-        app_label = 'calaccess_raw'
-        db_table = 'FILERNAME_CD'
-        verbose_name = 'FILERNAME_CD'
-        verbose_name_plural = 'FILERNAME_CD'
-        ordering = ("naml", "namf",)
-
-    def __unicode__(self):
-        return unicode(self.filer_id)
-
-
 class FilersCd(CalAccessBaseModel):
     filer_id = models.IntegerField(db_column='FILER_ID', db_index=True)
 
